Enum sirpent::state::grids::HexagonDirection
[−]
[src]
pub enum HexagonDirection {
North,
NorthEast,
SouthEast,
South,
SouthWest,
NorthWest,
}Variants
NorthNorthEastSouthEastSouthSouthWestNorthWestTrait Implementations
impl PartialEq for HexagonDirection[src]
fn eq(&self, __arg_0: &HexagonDirection) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for HexagonDirection[src]
impl Clone for HexagonDirection[src]
fn clone(&self) -> HexagonDirection
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Copy for HexagonDirection[src]
impl Hash for HexagonDirection[src]
fn hash<__H: Hasher>(&self, __arg_0: &mut __H)
Feeds this value into the state given, updating the hasher as necessary.
fn hash_slice<H>(data: &[Self], state: &mut H) where H: Hasher1.3.0
Feeds a slice of this type into the state provided.